@@ -13,9 +13,9 @@ create_visuals = function(data,fit,decoding,controls,events){
   if(is.na(controls[["controls_checked"]])){
     stop(sprintf("%s (%s)",exception("C.1")[2],exception("C.1")[1]),call.=FALSE)
   }
-  if(controls[["sim"]] || all(is.na(events))){
-    events = NA
-    warning(sprintf("%s (%s)",exception("V.1")[2],exception("V.2")[1]),call.=FALSE)
+  if(controls[["sim"]] & !is.null(events)){
+    events = NULL
+    warning(sprintf("%s (%s)",exception("V.1")[2],exception("V.1")[1]),call.=FALSE)
   } else {
     if(length(events[["dates"]])!=length(events[["names"]])){
       stop(sprintf("%s (%s)",exception("V.2")[2],exception("V.2")[1]),call.=FALSE)
@@ -23,9 +23,7 @@ create_visuals = function(data,fit,decoding,controls,events){
   }
   
   ### save events
-  if(!controls[["sim"]] & !is.na(events)){
-    check_saving(object = events, filetype = "rds", controls = controls)
-  }
+  if(!is.null(events)) check_saving(object = events, filetype = "rds", controls = controls)
   
   ### define colours
   var_col = function(col,n){
@@ -38,13 +36,13 @@ create_visuals = function(data,fit,decoding,controls,events){
     adjustcolor(col,alpha)
   }
   colors = list()
-  if(controls[["model"]]=="HMM"){
-    colors[["HMM"]] = col_alpha(base_col(controls[["states"]][1]))
+  if(controls[["model"]]=="hmm"){
+    colors[["hmm"]] = col_alpha(base_col(controls[["states"]][1]))
   }
-  if(controls[["model"]]=="HHMM"){
-    colors[["HHMM_cs"]] = col_alpha(base_col(controls[["states"]][1]))
+  if(controls[["model"]]=="hhmm"){
+    colors[["hhmm_cs"]] = col_alpha(base_col(controls[["states"]][1]))
     for(s in seq_len(controls[["states"]][1])){
-      colors[["HHMM_fs"]][[s]] = col_alpha(var_col(colors[["HHMM_cs"]][s],controls[["states"]][2]))
+      colors[["hhmm_fs"]][[s]] = col_alpha(var_col(colors[["hhmm_cs"]][s],controls[["states"]][2]))
     }
   }
   
@@ -57,5 +55,5 @@ create_visuals = function(data,fit,decoding,controls,events){
   ### compute, save, visualize and test pseudo-residuals
   pseudo_residuals(controls,data,fit,decoding)
   
-  message("Model results visualized")
+  message("Model results visualized.")
 }
