@@ -1,26 +1,24 @@
 #' @title Data simulation
 #' @description Simulates data from a (hierarchical) hidden Markov model.
 #' @param controls A list of controls.
-#' @param sim_par A list of model parameters for simulation in \code{thetaList} format, default \code{NA}.
+#' @param sim_par A list of model parameters for simulation in \code{thetaList} format.
 #' @return A list containing the following elements:
-#' \item{logReturns}{simulated log-returns}
-#' \item{states0}{simulated hidden states}
-#' \item{thetaUncon0}{true parameters in format \code{thetaUncon}}
-#' \item{thetaCon0}{true parameters in format \code{thetaCon}}
-#' \item{thetaList0}{true parameters in format \code{thetaList}}
-#' \item{T_star}{vector of fine-scale chunk sizes}
+#' \item{data}{A matrix of simulated data.}
+#' \item{states0}{A matrix of simulated hidden states.}
+#' \item{thetaUncon0}{True parameters in format \code{thetaUncon}.}
+#' \item{thetaCon0}{True parameters in format \code{thetaCon}.}
+#' \item{thetaList0}{True parameters in format \code{thetaList}.}
+#' \item{T_star}{A vector of fine-scale chunk sizes.}
 
-simulate_data = function(controls,sim_par=NA){
-  if(is.na(controls[["controls_checked"]])){
+simulate_data = function(controls, sim_par){
+  if(is.null(controls[["controls_checked"]]))
     stop(sprintf("%s (%s)",exception("F.6")[2],exception("F.6")[1]),call.=FALSE)
-  }
-  if(!is.null(controls[["fit"]][["seed"]])){
+  if(!is.null(controls[["fit"]][["seed"]]))
     set.seed(controls[["fit"]][["seed"]])
-  }
   T = as.numeric(controls[["horizon"]][1])
   
   ### define simulation parameters
-  if(!is.na(sim_par)){
+  if(!is.null(sim_par)){
     thetaUncon = thetaList2thetaUncon(sim_par,controls)
   } else {
     thetaUncon = init_est(controls)
@@ -42,43 +40,43 @@ simulate_data = function(controls,sim_par=NA){
   ### simulate observations
   simulate_observations = function(states,mus,sigmas,dfs,sdd){
     T = length(states)
-    logReturns = numeric(T)
+    data = numeric(T)
     for(t in 1:T){
       if(sdd == "t"){
-        logReturns[t] = rt(1,dfs[states[t]])*sigmas[states[t]]+mus[states[t]]
+        data[t] = rt(1,dfs[states[t]])*sigmas[states[t]]+mus[states[t]]
       }
       if(sdd == "gamma"){
-        logReturns[t] = rgamma(1,shape=mus[states[t]]^2/sigmas[states[t]]^2,scale=sigmas[states[t]]^2/mus[states[t]])
+        data[t] = rgamma(1,shape=mus[states[t]]^2/sigmas[states[t]]^2,scale=sigmas[states[t]]^2/mus[states[t]])
       }
     }
-    return(logReturns)
+    return(data)
   }
   
-  if(controls[["model"]]=="HMM"){
+  if(controls[["model"]]=="hmm"){
     T_star = NA
     states = simulate_states(Gamma2delta(thetaList[["Gamma"]]),thetaList[["Gamma"]],T) 
-    logReturns = simulate_observations(states,thetaList[["mus"]],thetaList[["sigmas"]],thetaList[["dfs"]],controls[["sdds"]][1])
+    data = simulate_observations(states,thetaList[["mus"]],thetaList[["sigmas"]],thetaList[["dfs"]],controls[["sdds"]][1])
   }
-  if(controls[["model"]]=="HHMM"){ 
+  if(controls[["model"]]=="hhmm"){ 
     T_star = compute_fs(fs_time_horizon = controls[["horizon"]][2], T = T)
     states = matrix(NA,T,max(T_star)+1) 
-    logReturns = matrix(NA,T,max(T_star)+1)
+    data = matrix(NA,T,max(T_star)+1)
     states[,1] = simulate_states(Gamma2delta(thetaList[["Gamma"]]),thetaList[["Gamma"]],T) 
-    logReturns[,1] = simulate_observations(states[,1],thetaList[["mus"]],thetaList[["sigmas"]],thetaList[["dfs"]],controls[["sdds"]][1])
+    data[,1] = simulate_observations(states[,1],thetaList[["mus"]],thetaList[["sigmas"]],thetaList[["dfs"]],controls[["sdds"]][1])
     for(t in 1:T){
       S_t = states[t,1]
       states[t,-1] = c(simulate_states(Gamma2delta(thetaList[["Gammas_star"]][[S_t]]),thetaList[["Gammas_star"]][[S_t]],T_star[t]),rep(NA,max(T_star)-T_star[t]))
-      logReturns[t,-1] = c(simulate_observations(states[t,-1][!is.na(states[t,-1])],thetaList[["mus_star"]][[S_t]],thetaList[["sigmas_star"]][[S_t]],thetaList[["dfs_star"]][[S_t]],controls[["sdds"]][2]),rep(NA,max(T_star)-T_star[t]))
+      data[t,-1] = c(simulate_observations(states[t,-1][!is.na(states[t,-1])],thetaList[["mus_star"]][[S_t]],thetaList[["sigmas_star"]][[S_t]],thetaList[["dfs_star"]][[S_t]],controls[["sdds"]][2]),rep(NA,max(T_star)-T_star[t]))
     }
   }
   
   out = list(
-    "logReturns"   = logReturns,
-    "states0"      = states,
-    "thetaUncon0"  = thetaUncon,
-    "thetaCon0"    = thetaCon,
-    "thetaList0"   = thetaList,
-    "T_star"       = T_star
+    "data"        = data,
+    "states0"     = states,
+    "thetaUncon0" = thetaUncon,
+    "thetaCon0"   = thetaCon,
+    "thetaList0"  = thetaList,
+    "T_star"      = T_star
   )
   return(out)
 }
\ No newline at end of file
